#pragma once

#include <memory>

namespace precice::partition {

class Partition;

using PtrPartition = std::shared_ptr<Partition>;

} // namespace precice::partition
